%bcond_without deflate
%bcond_without fuse
%bcond_without lz4
%bcond_without lzma
%bcond_without selinux
%bcond_without uuid
%bcond_without zlib

Name:           erofs-utils
Version:        1.8.6
Release:        %mkrel 1
Group:          System/Kernel and hardware
Summary:        Utilities for working with EROFS
License:        GPLv2+
URL:            https://git.kernel.org/pub/scm/linux/kernel/git/xiang/erofs-utils.git

Source0:        %{url}/snapshot/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  make
%if %{with deflate}
BuildRequires:  pkgconfig(libdeflate)
%endif
%if %{with fuse}
BuildRequires:  pkgconfig(fuse)
%endif
%if %{with lz4}
BuildRequires:  lz4-devel
%endif
%if %{with lzma}
BuildRequires:  pkgconfig(liblzma) >= 5.4
%endif
%if %{with selinux}
BuildRequires:  pkgconfig(libselinux)
%endif
%if %{with uuid}
BuildRequires:  pkgconfig(uuid)
%endif
%if %{with zlib}
BuildRequires:  pkgconfig(zlib)
%endif

%description
EROFS stands for Enhanced Read-Only File System.  Different from other
read-only file systems, it is designed for flexibility, scalability, and
simplicity for high performance.

This package includes tools to create, check, and extract EROFS images.

%if %{with fuse}
%package -n erofs-fuse
Summary:        FUSE support for mounting EROFS images
Requires:       fuse

%description -n erofs-fuse
EROFS stands for Enhanced Read-Only File System.  Different from other
read-only file systems, it is designed for flexibility, scalability, and
simplicity for high performance.

This package includes erofsfuse to mount EROFS images.
%endif


%prep
%autosetup

%build
autoreconf -fi
%configure \
    %{?with_deflate:--with-deflate} %{!?with_deflate:without-libdeflate} \
    %{?with_fuse:--enable-fuse} %{!?with_fuse:--disable-fuse} \
    %{?with_lz4:--enable-lz4} %{!?with_lz4:--disable-lz4} \
    %{?with_lzma:--enable-lzma} %{!?with_lzma:--disable-lzma} \
    %{?with_selinux:--with-selinux} %{!?with_selinux:--without-selinux} \
    %{?with_uuid:--with-uuid} %{!?with_uuid:--without-uuid} \
    %{?with_zlib:--with-zlib} %{!?with_zlib:--without-zlib}
%make_build

%install
%make_install


%files
%{_bindir}/dump.erofs
%{_bindir}/fsck.erofs
%{_bindir}/mkfs.erofs
%{_mandir}/man1/dump.erofs.1*
%{_mandir}/man1/fsck.erofs.1*
%{_mandir}/man1/mkfs.erofs.1*
%doc AUTHORS ChangeLog README
%license LICENSES/GPL-2.0


%if %{with fuse}
%files -n erofs-fuse
%{_bindir}/erofsfuse
%{_mandir}/man1/erofsfuse.1*
%doc AUTHORS ChangeLog README
%license LICENSES/GPL-2.0
%endif



%changelog
* Mon Jun 09 2025 daviddavid <daviddavid> 1.8.6-1.mga10
+ Revision: 2190136
- new version: 1.8.6

* Tue Sep 24 2024 daviddavid <daviddavid> 1.8.2-1.mga10
+ Revision: 2101041
- new version: 1.8.2

* Sat Jun 15 2024 daviddavid <daviddavid> 1.7.1-1.mga10
+ Revision: 2074380
- new version: 1.7.1, fixes CVE-2023-3355[12] (mga#32272)
- enable zlib and deflate support

* Thu Jun 16 2022 tv <tv> 1.5-1.mga9
+ Revision: 1864540
- Update to the 1.5 release.

* Wed Mar 30 2022 umeabot <umeabot> 1.4-3.mga9
+ Revision: 1833700
- Mageia 9 Mass Rebuild

* Fri Nov 26 2021 tv <tv> 1.4-2.mga9
+ Revision: 1759320
- Backport the patch to install a man page for fsck.
- Backport the patch to fix dump output.
- Move erofsfuse man-page into erofs-fuse package

* Mon Nov 22 2021 tv <tv> 1.4-1.mga9
+ Revision: 1758547
- Update to the 1.4 release.

* Fri Jun 04 2021 tv <tv> 1.3-1.mga9
+ Revision: 1729649
- 1.3
- 1.2.1

* Fri Dec 11 2020 tv <tv> 1.2-1.mga8
+ Revision: 1655449
- Update to the 1.2 release.
- Split FUSE support into an independent subpackage.

* Wed Apr 15 2020 tv <tv> 1.1-1.mga8
+ Revision: 1567563
- imported package erofs-utils


* Wed Apr 15 2020 Thierry Vignaud <tv@mageia.org> 1.1-1.mga8
- import from FC

* Mon Apr 13 2020 David Michael <fedora.dm0@gmail.com> - 1.1-1
- Update to the 1.1 release.

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Nov 25 2019 David Michael <fedora.dm0@gmail.com> - 1.0-1
- Initial package.
